@@ -131,7 +131,7 @@ class BoundingBox:
 
     @property
     def diameter(self):
-        return math.sqrt(self.w ** 2 + self.h ** 2)
+        return math.hypot(self.w, self.h)
 
     @property
     def aspect_ratio(self):
@@ -304,9 +304,11 @@ class Annotation:
         return key in self._fields
 
     def __repr__(self):
-        # only get fields that are not of type Annotation to prevent potentially infinite recursion
-        fields_str = ", ".join(f"{k}={v}" for k, v in self.extra_fields.items() if not isinstance(v, Annotation))
-        return f"{self.__class__.__name__}(category='{self.category}', bb={self.bb}, {fields_str})"
+        # use Annotation(...) to prevent potentially infinite recursion
+        cls_name = self.__class__.__name__
+        fields = (f"{k}={v if not isinstance(v, Annotation) else cls_name + '(...)'}" for k, v in
+                  self.extra_fields.items())
+        return f"{cls_name}(category='{self.category}', bb={self.bb}, {', '.join(fields)})"
 
 
 @dataclass
@@ -397,23 +399,31 @@ class AnnotatedImage:
         return s
 
 
+def get_scalar_map(n_categories, cmap: str):
+    """
+    Args:
+        n_categories: number of categories to compute a linear scalar map for
+        cmap: matplotlib cmap (other options include Dark2, Accent)
+    """
+    cm = plt.get_cmap(cmap)
+    norm = colors.Normalize(vmin=0, vmax=n_categories - 1)
+    return cmx.ScalarMappable(norm=norm, cmap=cm)
+
+
 def compute_colors(annotations: List[Annotation], categories: List[str], cmap='jet') -> List[np.ndarray]:
     """
-    :param annotations: list of annotations
-    :param categories: dataset categories
-    :param cmap: matplotlib cmap (other options include Dark2, Accent)
-    :return: a list with an rgba array for each annotation
+    Args:
+        annotations: list of annotations
+        categories: dataset categories
+        cmap: matplotlib cmap (other options include Dark2, Accent)
+    Returns:
+        a list with an RGBA array for each annotation
     """
     dataset_cat_to_id = {c: i for i, c in enumerate(categories)}
-
     cat_ids = np.array([dataset_cat_to_id[ann.category] for ann in annotations])
 
-    cm = plt.get_cmap(cmap)
-    cNorm = colors.Normalize(vmin=0, vmax=len(categories) - 1)
-    scalarMap = cmx.ScalarMappable(norm=cNorm, cmap=cm)
-    scalarMap.get_clim()
-
-    return [scalarMap.to_rgba(c) for c in cat_ids]
+    scalar_map = get_scalar_map(len(categories), cmap)
+    return [scalar_map.to_rgba(c) for c in cat_ids]
 
 
 def plot_anns(annotations: List[Annotation], categories: List[str] = None, ann_colors=None, ax=None, with_index=False,
@@ -431,6 +441,7 @@ def plot_anns(annotations: List[Annotation], categories: List[str] = None, ann_c
     :param digits: score digits
     :param min_score: score threshold for plotting the annotation
     :param draw_connections: draw arrow connections
+    :param draw_keypoints: draw arrow keypoints
     :param alpha_bb: alpha for the bounding box fill (not the border)
     :param alpha_txt: alpha for the text
     :param alpha_kp: alpha for scattered keypoints
@@ -445,6 +456,8 @@ def plot_anns(annotations: List[Annotation], categories: List[str] = None, ann_c
         _logger.warning("plot_anns: passed empty annotations list")
         return
 
+    annotations = [a for a in annotations if "score" not in a or a.score >= min_score]
+
     if ax is None:
         ax = plt.gca()
     if categories is None:
@@ -455,7 +468,7 @@ def plot_anns(annotations: List[Annotation], categories: List[str] = None, ann_c
         # assume only a single color has been passed
         ann_colors = [ann_colors] * len(annotations)
 
-    annotations = [a for a in annotations if "score" not in a or a.score >= min_score]
+    assert len(annotations) == len(ann_colors), f"{len(annotations)} != {len(ann_colors)}"
 
     # rough estimates so that text + kp sizes scale with figure size
     figsize = ax.figure.get_size_inches()
